@@ -23,6 +23,21 @@ sub symtab {
   *{globref(shift, '')}{HASH}
 }
 
+sub maybe_symtab {
+  my ($pack) = @_;
+  my @name = split /::/, $pack
+    or return undef;
+  shift @name if $name[0] eq "";
+  my $symtab = \%::;
+  foreach my $name (@name) {
+    my $glob = $symtab->{$name . "::"}
+      or return undef;
+    $symtab = *{$glob}{HASH}
+      or return undef;
+  }
+  $symtab;
+}
+
 sub safe_globref {
   my ($pack_or_obj, $name) = @_;
   unless (defined symtab($pack_or_obj)->{$name}) {
@@ -302,6 +317,31 @@ sub has_method_attr {
   grep {$_ eq 'method'} attributes::get($_[0])
 }
 
+use MOP4Import::FieldSpec qw(FieldSpec);
+
+sub list_validator {
+  my ($typeName) = @_;
+  my $fields = maybe_fields_hash($typeName)
+    or Carp::croak "Can't find type spec for $typeName";
+  my $names = fields_array($typeName);
+  my @names = $names ? @$names : sort keys %$fields;
+  map {
+    my FieldSpec $spec = $fields->{$_};
+    if (not UNIVERSAL::isa($spec, FieldSpec)) {
+      ()
+    }
+    elsif ($spec->{validator}) {
+      ($_ => $spec->{validator})
+    }
+    elsif ($spec->{isa}) {
+      ($_ => +{isa => $spec->{isa}, (exists $spec->{default} ? (default => $spec->{default}) : ())})
+    }
+    else {
+      ()
+    }
+  } @names;
+}
+
 #========================================
 
 sub m4i_log_start {
